/*
m_scene_bell_mf - Multifrequency tones used inside the old Bell network

DESCRIPTION
m_scene_bell_mf creates multifrequency tones that were used in the old Bell,
ATNT phone system to route calls. These could be heard as bleed. KP and KP2
have a length of 110ms plus the 55ms pause. All other "digits" have a length
of 55ms plus the 55ms pause.
NOTE: This is not the same as the DTMF tone dial system that phones still use.

SYNTAX
aOut m_scene_bell_mf Skey

INITIALIZATION
Skey - The key or digit to be rendered. Possible values:
	KP, KP2, ST and the digits 0-9. This _IS_ case sensitive!

PERFORMANCE
aOut - The multifrequency representation of the key

CREDITS
Author: Jeanette C., thanks to Evan Doorbell and other phone phreaks of the time
for their extensive recordings and documentation.
*/

opcode m_scene_bell_mf, a, S
	Skey xin

	; Set up basic variables
	kFreq1 init 0
	kFreq2 init 0

	; Set up ftables with the necessary frequencies
	iFreq1 ftgenonce 0, 0, 13, -2, 1100, 1300, 700, 700, 900, 700, 900, 1100, \
		700, 900, 1100, 1300, 1500
	iFreq2 ftgenonce 0, 0, 13, -2, 1700, 1700, 900, 1100, 1100, 1300, 1300, \
		1300, 1500, 1500, 1500, 1500, 1700

	; Create a sine wave
	iSine ftgenonce 0, 0, 32768, 10, 1
	
	; Check key and set frequencies
	if (strcmp(Skey, "KP") == 0) then
		kFreq1 table 0, iFreq1, 0
		kFreq2 table 0, iFreq2, 0
	elseif (strcmp(Skey, "KP2") == 0) then
		kFreq1 table 1, iFreq1, 0
		kFreq2 table 1, iFreq2, 0
	elseif (strcmp(Skey, "1") == 0) then
		kFreq1 table 2, iFreq1, 0
		kFreq2 table 2, iFreq2, 0
	elseif (strcmp(Skey, "2") == 0) then
		kFreq1 table 3, iFreq1, 0
		kFreq2 table 3, iFreq2, 0
	elseif (strcmp(Skey, "3") == 0) then
		kFreq1 table 4, iFreq1, 0
		kFreq2 table 4, iFreq2, 0
	elseif (strcmp(Skey, "4") == 0) then
		kFreq1 table 5, iFreq1, 0
		kFreq2 table 5, iFreq2, 0
	elseif (strcmp(Skey, "5") == 0) then
		kFreq1 table 6, iFreq1, 0
		kFreq2 table 6, iFreq2, 0
	elseif (strcmp(Skey, "6") == 0) then
		kFreq1 table 7, iFreq1, 0
		kFreq2 table 7, iFreq2, 0
	elseif (strcmp(Skey, "7") == 0) then
		kFreq1 table 8, iFreq1, 0
		kFreq2 table 8, iFreq2, 0
	elseif (strcmp(Skey, "8") == 0) then
		kFreq1 table 9, iFreq1, 0
		kFreq2 table 9, iFreq2, 0
	elseif (strcmp(Skey, "9") == 0) then
		kFreq1 table 10, iFreq1, 0
		kFreq2 table 10, iFreq2, 0
	elseif (strcmp(Skey, "0") == 0) then
		kFreq1 table 11, iFreq1, 0
		kFreq2 table 11, iFreq2, 0
	elseif (strcmp(Skey, "ST") == 0) then
		kFreq1 table 12, iFreq1, 0
		kFreq2 table 12, iFreq2, 0
	endif

	; Set up volume envelope
	if ((strcmp(Skey, "KP") == 0) || (strcmp(Skey, "KP2") == 0)) then
		kAmpEnv linseg .5, .11, .5, 0, 0, .055, 0
	else
		kAmpEnv linseg .5, .055, .5, 0, 0, .055, 0
	endif
	
	; Create the audio signals
	aFreq1 oscil 1, kFreq1, iSine
	aFreq2 oscil 1, kFreq2, iSine
	aOut = (aFreq1 + aFreq2) * kAmpEnv

	xout aOut
endop
