/*
m_scene_bell_pd - Old American Bell style pulse dialing

DESCRIPTION
m_scene_bell_pd is the modelling of old pulse dialing. The distance between
the pulses is in accordance with ATNT specs (0.1 second perpulse)
NOTE: a time of one second is recommended for each digit. Slightly longer
for 0, since it takes exactly one second to dial.

SYNTAX
aOut m_scene_bell_pd kDigit, kQuality, kStyle

INITIALIZATION

PERFORMANCE
kDigit - Digit to dial, 0 to 9
kQuality - Highend quality, between 0 and 1
kStyle - Style of the pulses, The following values are allowed:
	0: Pulse wave with narrow pulsewidth
	1: Triangle

CREDITS
Author: Jeanette C.
*/

opcode m_scene_bell_pd, a, kkk
	kDigit, kQuality, kStyle xin

	; Calculate values from parameters
	kLowpassFreq linlin kQuality, 2000, 8000

	; Set up volume envelope matching the dialed digit
	if (i(kDigit) == 0) then
		iLength = 1
	else
		iLength = i(kDigit) * .1
	endif

	if (iLength > p3) then ; not enough time
		xtratim (iLength - p3)
	endif

	; Set pulse tone and adjust maximum volume
	if (i(kStyle) == 0) then
		iShape = 2
		iVolume = .53
	else
		iShape = 4
		iVolume = 1.3
	endif

	kAmpEnv linseg iVolume, (iLength - .001), iVolume, .001, 0

	; Set up ftable for the pulse gating and the gate
	iPuls ftgenonce 0, 0, 4096, 7, 1, 511, 1, 1, 0, 3584, 0
	kGate oscil .9, 10, iPuls
	aPuls vco2 kGate*kAmpEnv, 60, iShape, .05
	aLowpass butterlp aPuls, kLowpassFreq
	aOut butterhp aLowpass, 200
	xout aOut
endop
