/*
m_scene_bell_phone - Old (60s and 70s) phone speaker immitation

DESCRIPTION
This is the effect of passing a signal through an old telephone. It is not
modelled, simply imitated by ear and a few facts.

SYNTAX
aOut m_scene_bell_phone aInput, kBandwidth, kQuality

INITIALIZATION

PERFORMANCE
aInput - Input audio signal
aOut - Processed audio output signal
kBandwidth - Bandwidth of the output, between 0 and 1
kQuality - Quality of the output (distortion and mid cut), between 0 and 1

CREDITS
Author: Jeanette C., thanks to Evan Doorbell and other phone phreaks of the
time for their extensive recordings and documentation.
*/

opcode m_scene_bell_phone, a, akk
	aInput, kBandwidth, kQuality xin

	; Create a sine wave
	iSine ftgenonce 0, 0, 32768, 10, 1

	; Calculate values from parameters
	kHighpass linlin kBandwidth, 2500, 500
	kLowpass linlin kBandwidth, 500, 4000
	kVolume linlin kBandwidth, 10, 1
	kDipFreq linlin kQuality, 1600, 800
	kDipLevel linlin kQuality, .9, -.7
	kDistort linlin kQuality, .5, 0

	; Distort the signal
	aDistort distort aInput, kDistort, iSine

	; Highpass filter the input
	aHighpass zdf_2pole aDistort*kVolume, kHighpass, 1, 1
	aLowpass zdf_2pole aHighpass, kLowpass, 1, 0
	aPeak pareq aLowpass, kDipFreq, kDipLevel, .4

	aOut limit aPeak, -1, 1

	xout aOut
endop
